CarDekho - Cars in India, New Cars Prices Sat Dec 06 08:26:37 IST 2014, Buy and Sell Used Cars | CarDekho.com
Description: CarDekho.com - Find New Cars in India, Upcoming & Latest Car Prices in Sat Dec 06 08:26:37 IST 2014. Buy and Sell Used Cars. Read Car Reviews, Compare Cars and view Car Pictures.
Keywords: new cars, new cars Sat Dec 06 08:26:37 IST 2014, new car prices, car prices,India car, new car Sat Dec 06 08:26:37 IST 2014,cars India, new car, car prices in india, used car, used cars, used cars for sale, used cars india, buy used cars, sell cars, sell used cars, indian cars, cars Sat Dec 06 08:26:37 IST 2014, cars in india

Search
your new car at CarDekho

- New Car
- Used Car

By Budget
By Brand
By Budget
By Model
Featured Car of December 2014
Volkswagen Polo
Featured Car of December 2014
Maruti Alto K10
Featured Car of December 2014
Maruti Ciaz
Featured Car of December 2014
Mahindra Scorpio
Featured Car of December 2014
Hyundai i20
Featured Car of December 2014
Tata Zest
Featured Car of December 2014
Honda Mobilio
Suno Nahi,
Dekho

## TOOLS & SERVICES

- On Road Price
- EMI Calculator
- Car Valuation
- Road Test
- Loans
- User Reviews
- Videos
- Shell Helix

## CARDEKHO GUIDE

Top-5 Upcoming Hatchbacks in India
What are crossover vehicles?
Renault is Offering Scala RxL Diesel at petrol counterpart price - Rs. 8.01 Lac!
AMT to rule 30% of Vehicles in Next Five Years

## Latest cars in Sat Dec 06 08:26:37 IST 2014

- ### Latest

- ### Upcoming

- ### Popular

- Porsche Cayenne
  `1.0 - 1.8 Cr*

  - Advertisement

  - BMW M Series
    `1.2 - 1.8 Cr*
  - Mercedes-Benz C-Class
    `40.9 - 40.9 Lac*
  - Mini 3 DOOR
    `31.8 - 31.8 Lac*
  - Mini 5 DOOR
    `35.2 - 35.2 Lac*
  *Ex-showroom Price New Delhi
  VIEW MORE LATEST CARS
- Maruti Ciaz
  `10.2 Lac* | Launch Date: 2014-12-07

  - Advertisement

  - Audi A3 cabriolet
    `22.5 Lac*
    Launch Date: 2014-12-12
  - BMW X6
    `93.4 Lac*
    Launch Date: 2014-12-30
  - Datsun GO Plus
    `5.0 Lac*
    Launch Date: 2015-01-22
  - Mitsubishi Mirage
    `5.0 Lac*
    Launch Date: 2015-01-30
  *Estimated Price
  VIEW MORE UPCOMING CARS
- Maruti Alto K10
  `3.0 - 3.8 Lac*

  - Advertisement

  - Hyundai Elite i20
    `5.0 - 7.7 Lac*
  - Maruti Swift
    `4.4 - 7.0 Lac*
  - Maruti Ciaz
    `7.0 - 9.8 Lac*
  - Honda Mobilio
    `6.5 - 11.5 Lac*
  *Ex-showroom Price New Delhi
  VIEW MORE POPULAR CARS

## Popular Brands

View More

## LATEST NEWS

Latest Automobile News in India - View All

Q7 To Be Audis First Vehicle To Get Plug-in Hybrid Diesel Powertrain

- Fri Dec 05 18:37:17 IST 2014

  #### 2015 BMW 1 Series Facelift Spied

  BMW has started testing the facelifted version of 1 Series hatch, both the 3-doors (not available in [...]

- Fri Dec 05 18:21:17 IST 2014

  #### Mercedes-Benz inaugurates new dealership in Chandigarh

  After Mumbai and Surat quite recently, Mercedes-Benz India today inaugurated a new outlet- Joshi Aut [...]

## Featured Stories

Read More Stories from Experts - View All

The Great Mahindra Off-Road Challenge
A Nano-licious Time
Vredestein tyres from Apollo
How Electronic Stability Program will save your life
Headlight technologies Adaptive, cornering lights, self leveling lights

## Expert Reviews

See what the experts have to say - View All

- Fri Dec 05 16:01:05 IST 2014

  #### Volkswagen Polo GT TSI: Expert review

  Things to look forward to:

  [...]

- 2014-11-27 12:23:57.0

  #### Maruti Suzuki Swift

  Maruti gives its largest selling model a facelift. Is the new Swift worth the effort to be re-crowne [...]

## POPULAR USED CARS

- ### Used Cars In Delhi (9527)

- ### Used Cars In Mumbai (3605)

- ### Used Cars In Bangalore (2510)

- ### Used Cars In Chennai (2581)

- ### Used Cars In Hyderabad (2264)

- ### Used Cars In Pune (2618)

- ### Used Cars In Kolkata (1468)

- ### Used Cars In Gurgaon (1586)

- ### Used Cars In Jaipur (1286)

- ### Used Cars In Patna (392)

- ### Used Cars In Cochin (273)

- ### Used Cars In Noida (733)

VIEW MORE USED CARS

## LATEST VIDEOS

- ### The New Generation Mahindra Scorpio

- ### Honda Mobilio Video Review

- ### BMW 328i Road Test Video

VIEW MORE VIDEOS

### USER REVIEWS

- tata zest: the best car with best driving modes
  By JITENDRA KHATRI, Fri Dec 05 13:16:24 IST 2014

  look and style: looks are good, attractive and can compete with hyundai verna in terms of looks. co...

- value for money
  By RAJ, 2014-12-02 12:09:24.0

  look and style - ok but not elegant. design statement could have been made more sleek with tinkering...

VIEW MORE USER REVIEWS

### ASK US

- Q
  hi, my requirement is as follows 1. budget is 7 lakh 2. should have abs/ebd and nice to have features 3. should have dri...?
  By nagarjun, 2014-12-05 11:35:48.0
- Q
  what is the dust impact on vehicle quality? please explain in details. it would better if you give country specific stat...?
  By tejas, 2014-12-05 10:20:41.0
- Q
  what is the mileage of mobilio, petrol model while in city with ac?
  By ashutosh gupta, 2014-12-04 20:47:25.0

ASK A QUESTION

CarDekho is not just a web portal that lists cars in India, but is a rich automotive platform that brings to its readers to-the-minute insights from around the world. Be it a newbie, an auto freak, or a layman in terms of complex car engine and performance terminologies, CarDekho is the place where you can read fresh news, and road tests; browse recently shot images and videos, compare car features, prices, and other car specifications. See More...

### Buy a New Car

CarDekho lists over 197 new cars from across the brands. Pick any four of your interest and compare them here. Comparison gives a crystal clear distinction between the chosen four. Read expert opinions on why to select a particular model over others. Once you've made your choice, CarDekho vehicle loan assistance and Insurance team will help you with the essential paper work making new car buying a pleasant experience for you. Moreover, CarDekho connects to thousands of car dealers across India. Visit the Car Dealers in India page, select your city and find the contact information as well as the location of your nearest dealer.

### We help you Sell your used car

Wish to sell your old car? List the used car Free of cost, at CarDekho, and enjoy an immediate response from the prospective buyers. CarDekho doesn't charge for a regular used car listing, but if you are willing to bring your listing to the forefront, we charge a minimal amount helping you sell used car immediately. List your used car now.

### Wish to buy a second hand car?

If you are looking for an old yet sophisticated used car, we list over 25033 Used cars, where you can filter your favorite brands and models. If not sure about what model to buy, simply filter your search, based on the price range that you can afford and explore the listed used cars. CarDekho allows used car buyers to contact the used car sellers directly, meaning that the deal is going to happen without our involvement. You negotiate with the seller directly and finalize the deal. No commission is payable to CarDekho! Isn't that just great! Browse the used cars in India now.

### Are you an auto addict? Be a part of CarDekho Forum

There are thousands who are waiting for valuable expert opinion on a wide range of topics pertaining to motoring. If you are knowledgeable about certain aspects of motoring, we welcome you to be a part of Forum.Cardekho.com and help our readers with answers to their queries. If you are a starter, you may get into a discussion to clear any doubts or confusion, by asking anything related to cars. Post spy images, videos and share scoops with us to get rewards.

Thousands of happy customers buy used and new cars through us every month. Who knew it was so easy to buy cars in India online?

Collapse...

My Comparison

Compare Now